import error

__version__ = (0, 1, 0)
class Base:
    pass

class Balance(Base):
    def __init__(self, balance, locked=False):
        self.__balance = balance
        self.__locked = locked

    def getbalance(self):
        return self.__balance

    def setbalance(self, balance):
        if self.__locked:
            raise error.LockedBalance("Balance is already locked.")
        if balance < 0 or balance > 10 ** 7:
            raise error.OutOfRangeError("Given value out of range.")
        self.__balance = balance
        return

    def setlocked(self):
        self.__locked = True

    def __add__(self, b):
        if not isinstance(b, Balance):
            raise TypeError("Operation require 2 or more balances.")
        self.__balance = self.__balance + b.getbalance()
        return self

    def __sub__(self, b):
        if not isinstance(b, Balance):
            raise TypeError("Operation require 2 or more balances.")
        self.__balance = self.__balance - b.getbalance()
        return self

    def __mul__(self, b):
        if not isinstance(b, float):
            raise TypeError("Operation require a balance and an float, not 2 balances.")
        self.__balance = self.__balance + b
        return self

    def __div__(self, b):
        if not isinstance(b, float):
            raise TypeError("Operation require a balance and an float, not 2 balances.")
        self.__balance = self.__balance + b
        return self

class BaseProduct(Base):
    def __init__(self, name, price):
        self.name = name
        self.__price = price
        return
    def getprice(self):
        return self.__price
    def setprice(self, price):
        self.__price = price
        return 0
    def fmt_print(self):
        print(f"Product: {self.name} ${self.getprice()}")
        return 0
    def fmt(self):
        return f"Product: {self.name} ${self.__price}"




class BaseCheckoutError(RuntimeError):
    "Do not raise, but can be catched."
    pass

class IllegalInputError(BaseCheckoutError):
    "General illegal input."
    pass

class IllegalOperationError(BaseCheckoutError):
    "General illegal operation."
    pass

class OutOfRangeError(IllegalInputError):
    "Only for illegal inputs that ar out of range."
    pass

class DisabledValueError(IllegalInputError):
    "For illegal inputs that are currently disabled."
    pass

class LockedBalance(IllegalOperationError):
    "Operations on balances that are locked."
    pass


import setuptools
import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / "README.md").read_text(encoding="utf-8")
setuptools.setup(
    name = "CMLv1",
    version = "0.1.0",
    author="fyc",
    author_email="fycsfls_winter@126.com",
    description = "A support library for CheckoutMachineApplication.",
    readme = "README.md",
    python_requires = ">=3.7",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    classifiers = [
        "Programming Language :: Python :: 3",
        "Development Status :: 2 - Pre-Alpha",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    project_urls = {
        "Documentation" : "https://you.wont.expect.me.to.give.you.a.documentation.right/"
    }
)
